@@ -15,9 +15,9 @@ import statistics as st
 
 import math
 
-from .help import refmfe, SHIFT_CONST
+from premirnaplot.help import refmfe, SHIFT_CONST
 
-from .imgparser import SVGconstructor
+from premirnaplot.imgparser import SVGconstructor
 
 
 
